(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     57272,       1587]
NotebookOptionsPosition[     54384,       1483]
NotebookOutlinePosition[     55038,       1508]
CellTagsIndexPosition[     54951,       1503]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<SpinDynamica`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.450336910857295*^9, 3.450336917940371*^9}, {
  3.568902250118079*^9, 3.5689022569744716`*^9}}],

Cell[BoxData[
 TagBox[
  FrameBox["\<\"SpinDynamica version 3.0.1 loaded\"\>"],
  DisplayForm]], "Print",
 CellChangeTimes->{3.7121605957382097`*^9}],

Cell[BoxData[
 TemplateBox[{
  "ModifyBuiltIn","report",
   "\"The following built-in routines have been modified in SpinDynamica: \\!\
\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"Chop\\\", \\\",\\\", \\\"Dot\\\", \
\\\",\\\", \\\"Duration\\\", \\\",\\\", \\\"Exp\\\", \\\",\\\", \
\\\"Expand\\\", \\\",\\\", \\\"ExpandAll\\\", \\\",\\\", \\\"NumericQ\\\", \\\
\",\\\", \\\"Plus\\\", \\\",\\\", \\\"Power\\\", \\\",\\\", \\\"Simplify\\\", \
\\\",\\\", \\\"Times\\\", \\\",\\\", \\\"WignerD\\\"}], \\\"}\\\"}]\\). \
\\nEvaluate \
??\\!\\(\\*\\nStyleBox[\\\"symbol\\\",\\nFontSlant->\\\"Italic\\\"]\\) to \
generate the additional definitions for \
\\!\\(\\*\\nStyleBox[\\\"symbol\\\",\\nFontSlant->\\\"Italic\\\"]\\).\"",2,1,
   1,29119468654816436201,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.712160596893224*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["opR (rotation operators)", "Subsubtitle",
 CellChangeTimes->{{3.456163949016762*^9, 3.4561639600646276`*^9}, {
  3.502944767095223*^9, 3.5029447709877853`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "opR"}]], "Input",
 CellChangeTimes->{{3.5029428509553127`*^9, 3.502942851564311*^9}, {
  3.502944772759568*^9, 3.502944773205044*^9}}],

Cell[BoxData[
 StyleBox["\<\"opR[spins,angle] is the operator for rotating a single spin or \
a set of spins through the specified angle. If spins is absent, all spins in \
the current SpinSystem are rotated. The following formats for angle may be \
used: 1. {\[Beta],\[Phi]} indicates a rotation through \[Beta] about an axis \
in the xy plane with the phase \[Phi]. The phase value may either be numeric, \
or be specified using the text codes \\\"x\\\", \\\"y\\\", \\\"-x\\\" for the \
quadrature phases. A code \\\"z\\\" indicates a rotation about the z-axis. 2. \
The format {\[Xi],{\[Theta],\[Phi]}} indicates a rotation through the angle \
\[Xi] about an axis with polar angles \[Theta] and \[Phi]. 3. The format {\
\[Alpha],\[Beta],\[Gamma]} indicates a rotation through the specified Euler \
angles, using the zyz convention.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.7121605972593803`*^9},
 CellTags->"Info23712164197-7500259"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1 spins-1/2", "Subsection",
 CellChangeTimes->{{3.50294288940539*^9, 3.502942891122905*^9}, 
   3.5029447947655487`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetSpinSystem", "[", "1", "]"}]], "Input",
 CellChangeTimes->{{3.502944802357457*^9, 3.5029448052451*^9}}],

Cell[BoxData[
 TemplateBox[{
  "SetSpinSystem","set",
   "\"the spin system has been set to \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\
\\\"]}], \\\"}\\\"}], \\\"}\\\"}]\\)\"",2,3,2,29119468654816436201,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.502944805674008*^9, 3.515083883593923*^9, 
  3.5689022672290583`*^9, 3.7121605972823935`*^9}],

Cell[BoxData[
 TemplateBox[{
  "SetBasis","set",
   "\"the state basis has been set to \\!\\(\\*RowBox[{\\\"ZeemanBasis\\\", \
\\\"[\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \
\\\",\\\", FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}], \\\"}\\\"}], \
\\\",\\\", RowBox[{\\\"BasisLabels\\\", \\\"\[Rule]\\\", \
\\\"Automatic\\\"}]}], \\\"]\\\"}]\\).\"",2,3,3,29119468654816436201,"Local"},
  
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.502944805674008*^9, 3.515083883593923*^9, 
  3.5689022672290583`*^9, 3.712160597340334*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opR", "[", 
  RowBox[{"{", 
   RowBox[{"\[Beta]", ",", "\"\<x\>\""}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.456163969817183*^9, 3.456163972342784*^9}, {
  3.502944779974739*^9, 3.502944787933227*^9}, {3.502944853063242*^9, 
  3.502944853357257*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{
   SubscriptBox["R", 
    RowBox[{"1", "x"}]], "(", "\[Beta]", ")"}],
  DisplayForm]], "Output",
 CellChangeTimes->{
  3.456163972928733*^9, {3.4561642866194344`*^9, 3.456164305639657*^9}, 
   3.456164374866177*^9, 3.456164594717111*^9, 3.456201554603448*^9, 
   3.456201608289055*^9, 3.45620218033608*^9, 3.4562024984610767`*^9, 
   3.4562028144070063`*^9, 3.456203069298373*^9, 3.456204079892432*^9, 
   3.4562041416379223`*^9, 3.456204495705676*^9, 3.4562045479051867`*^9, 
   3.4562045836977177`*^9, 3.4562048553454227`*^9, 3.4562048988566723`*^9, 
   3.461036948876019*^9, 3.461066147178043*^9, 3.50294277143346*^9, {
   3.5029430461276293`*^9, 3.5029430543842297`*^9}, {3.5029447885632877`*^9, 
   3.502944807849169*^9}, 3.502944853939891*^9, 3.5150838836311083`*^9, 
   3.568902269801205*^9, 3.7121605973508387`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"opR", "[", 
    RowBox[{"{", 
     RowBox[{"\[Beta]", ",", "\"\<x\>\""}], "}"}], "]"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.50294483900352*^9, 3.5029448570856543`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"Cos", "[", 
       FractionBox["\[Beta]", "2"], "]"}], 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}]},
     {
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}], 
      RowBox[{"Cos", "[", 
       FractionBox["\[Beta]", "2"], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {2, 2}, 0, {
     1, {{0, 2, 4}, {{1}, {2}, {1}, {2}}}, {
      Cos[Rational[1, 2] $CellContext`\[Beta]], Complex[0, -1] 
       Sin[Rational[1, 2] $CellContext`\[Beta]], Complex[0, -1] 
       Sin[Rational[1, 2] $CellContext`\[Beta]], Cos[
       Rational[1, 2] $CellContext`\[Beta]]}}]]]]], "Output",
 CellChangeTimes->{{3.502944849565392*^9, 3.502944857672983*^9}, 
   3.515083883662446*^9, 3.568902285904126*^9, 3.712160597400876*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"opR", "[", 
    RowBox[{"{", 
     RowBox[{"\[Beta]", ",", "\[Phi]"}], "}"}], "]"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.50294483900352*^9, 3.502944865925602*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"Cos", "[", 
       FractionBox["\[Beta]", "2"], "]"}], 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}]},
     {
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}], 
      RowBox[{"Cos", "[", 
       FractionBox["\[Beta]", "2"], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {2, 2}, 0, {
     1, {{0, 2, 4}, {{1}, {2}, {1}, {2}}}, {
      Cos[Rational[1, 2] $CellContext`\[Beta]], Complex[0, -1] 
       E^(Complex[0, -1] $CellContext`\[Phi]) 
       Sin[Rational[1, 2] $CellContext`\[Beta]], Complex[0, -1] 
       E^(Complex[0, 1] $CellContext`\[Phi]) 
       Sin[Rational[1, 2] $CellContext`\[Beta]], Cos[
       Rational[1, 2] $CellContext`\[Beta]]}}]]]]], "Output",
 CellChangeTimes->{{3.502944849565392*^9, 3.502944866612155*^9}, 
   3.515083883717142*^9, 3.5689022884582725`*^9, 3.7121605974924393`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"opR", "[", 
    RowBox[{"{", 
     RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]"}], "}"}], "]"}], 
   "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.50294483900352*^9, 3.502944876181622*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", "\[Alpha]"}], "2"]}], "-", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", "\[Gamma]"}], "2"]}]], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "\[Alpha]"}], "2"]}], "+", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", "\[Gamma]"}], "2"]}]]}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}]},
     {
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", "\[Alpha]"}], "2"], "-", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", "\[Gamma]"}], "2"]}]], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", "\[Alpha]"}], "2"], "+", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", "\[Gamma]"}], "2"]}]], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {2, 2}, 0, {
     1, {{0, 2, 4}, {{1}, {2}, {1}, {2}}}, {
      E^(Complex[0, Rational[-1, 2]] $CellContext`\[Alpha] + 
         Complex[0, Rational[-1, 2]] $CellContext`\[Gamma]) 
       Cos[Rational[1, 2] $CellContext`\[Beta]], -
       E^(Complex[0, Rational[-1, 2]] $CellContext`\[Alpha] + 
         Complex[0, Rational[1, 2]] $CellContext`\[Gamma]) 
       Sin[Rational[1, 2] $CellContext`\[Beta]], 
       E^(Complex[0, Rational[1, 2]] $CellContext`\[Alpha] + 
         Complex[0, Rational[-1, 2]] $CellContext`\[Gamma]) 
       Sin[Rational[1, 2] $CellContext`\[Beta]], 
       E^(Complex[0, Rational[1, 2]] $CellContext`\[Alpha] + 
         Complex[0, Rational[1, 2]] $CellContext`\[Gamma]) 
       Cos[Rational[1, 2] $CellContext`\[Beta]]}}]]]]], "Output",
 CellChangeTimes->{{3.502944849565392*^9, 3.502944876877028*^9}, 
   3.5150838837963867`*^9, 3.568902292822522*^9, 3.712160597540474*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"opR", "[", 
    RowBox[{"{", 
     RowBox[{"\[Xi]", ",", 
      RowBox[{"{", 
       RowBox[{"\[Theta]", ",", "\[Phi]"}], "}"}]}], "}"}], "]"}], "]"}], "//",
   "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.50294483900352*^9, 3.502944892261561*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "2"]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", "\[Xi]"}], "2"]}], "-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "2"]}]], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            FractionBox["\[Theta]", "2"], "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", "\[Xi]"}], "2"], "-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "2"]}]], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            FractionBox["\[Theta]", "2"], "]"}], "2"]}]}], ")"}]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "2"]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", "\[Xi]"}], "2"]}], "-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "2"]}]], " ", 
          RowBox[{"Cos", "[", 
           FractionBox["\[Theta]", "2"], "]"}], " ", 
          RowBox[{"Sin", "[", 
           FractionBox["\[Theta]", "2"], "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", "\[Xi]"}], "2"], "-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "2"]}]], " ", 
          RowBox[{"Cos", "[", 
           FractionBox["\[Theta]", "2"], "]"}], " ", 
          RowBox[{"Sin", "[", 
           FractionBox["\[Theta]", "2"], "]"}]}]}], ")"}]}]},
     {
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "2"]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", "\[Xi]"}], "2"]}], "+", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "2"]}]], " ", 
          RowBox[{"Cos", "[", 
           FractionBox["\[Theta]", "2"], "]"}], " ", 
          RowBox[{"Sin", "[", 
           FractionBox["\[Theta]", "2"], "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", "\[Xi]"}], "2"], "+", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "2"]}]], " ", 
          RowBox[{"Cos", "[", 
           FractionBox["\[Theta]", "2"], "]"}], " ", 
          RowBox[{"Sin", "[", 
           FractionBox["\[Theta]", "2"], "]"}]}]}], ")"}]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "2"]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", "\[Xi]"}], "2"], "+", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "2"]}]], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            FractionBox["\[Theta]", "2"], "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", "\[Xi]"}], "2"]}], "+", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "2"]}]], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            FractionBox["\[Theta]", "2"], "]"}], "2"]}]}], ")"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {2, 2}, 0, {
     1, {{0, 2, 4}, {{1}, {2}, {1}, {2}}}, {
      E^(Complex[0, Rational[1, 2]] $CellContext`\[Phi]) (
        E^(Complex[0, Rational[-1, 2]] $CellContext`\[Xi] + 
           Complex[0, Rational[-1, 2]] $CellContext`\[Phi]) 
         Cos[Rational[1, 2] $CellContext`\[Theta]]^2 + 
        E^(Complex[0, Rational[1, 2]] $CellContext`\[Xi] + 
           Complex[0, Rational[-1, 2]] $CellContext`\[Phi]) 
         Sin[Rational[1, 2] $CellContext`\[Theta]]^2), 
       E^(Complex[0, Rational[-1, 2]] $CellContext`\[Phi]) (
        E^(Complex[0, Rational[-1, 2]] $CellContext`\[Xi] + 
           Complex[0, Rational[-1, 2]] $CellContext`\[Phi]) 
         Cos[Rational[1, 2] $CellContext`\[Theta]] 
         Sin[Rational[1, 2] $CellContext`\[Theta]] - 
        E^(Complex[0, Rational[1, 2]] $CellContext`\[Xi] + 
          Complex[0, Rational[-1, 2]] $CellContext`\[Phi]) 
        Cos[Rational[1, 2] $CellContext`\[Theta]] 
        Sin[Rational[1, 2] $CellContext`\[Theta]]), 
       E^(Complex[0, Rational[1, 2]] $CellContext`\[Phi]) (
        E^(Complex[0, Rational[-1, 2]] $CellContext`\[Xi] + 
           Complex[0, Rational[1, 2]] $CellContext`\[Phi]) 
         Cos[Rational[1, 2] $CellContext`\[Theta]] 
         Sin[Rational[1, 2] $CellContext`\[Theta]] - 
        E^(Complex[0, Rational[1, 2]] $CellContext`\[Xi] + 
          Complex[0, Rational[1, 2]] $CellContext`\[Phi]) 
        Cos[Rational[1, 2] $CellContext`\[Theta]] 
        Sin[Rational[1, 2] $CellContext`\[Theta]]), 
       E^(Complex[0, Rational[-1, 2]] $CellContext`\[Phi]) (
        E^(Complex[0, Rational[1, 2]] $CellContext`\[Xi] + 
           Complex[0, Rational[1, 2]] $CellContext`\[Phi]) 
         Cos[Rational[1, 2] $CellContext`\[Theta]]^2 + 
        E^(Complex[0, Rational[-1, 2]] $CellContext`\[Xi] + 
           Complex[0, Rational[1, 2]] $CellContext`\[Phi]) 
         Sin[Rational[1, 2] $CellContext`\[Theta]]^2)}}]]]]], "Output",
 CellChangeTimes->{{3.502944849565392*^9, 3.5029448930503273`*^9}, 
   3.5150838838679237`*^9, 3.568902296176714*^9, 3.7121605986083403`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2 spins-1/2", "Subsection",
 CellChangeTimes->{{3.50294288940539*^9, 3.502942891122905*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetSpinSystem", "[", "2", "]"}]], "Input",
 CellChangeTimes->{{3.45616396286911*^9, 3.45616396576895*^9}, 
   3.456201606022471*^9, 3.456204541615698*^9, 3.456204576928049*^9}],

Cell[BoxData[
 TemplateBox[{
  "SetSpinSystem","set",
   "\"the spin system has been set to \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \
FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\
\\\"]}], \\\"}\\\"}]}], \\\"}\\\"}]\\)\"",2,9,4,29119468654816436201,"Local"},
  
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.456163966369556*^9, {3.456164286553218*^9, 3.45616430554272*^9}, 
   3.456164374062786*^9, 3.456164593915292*^9, 3.4562015544899282`*^9, 
   3.456201608205554*^9, 3.4562021802379427`*^9, 3.456202498330545*^9, 
   3.4562028142931004`*^9, 3.456203069214973*^9, 3.456204078992474*^9, 
   3.456204140752467*^9, 3.456204494804265*^9, 3.4562045420959673`*^9, {
   3.456204577367599*^9, 3.456204583615263*^9}, 3.456204854481304*^9, 
   3.45620489799152*^9, 3.461036948022011*^9, 3.461066145853022*^9, 
   3.502942771367139*^9, {3.502943046043352*^9, 3.5029430543488607`*^9}, 
   3.502944776994608*^9, 3.5029449033425407`*^9, 3.51508388392794*^9, 
   3.568902299239889*^9, 3.712160598769956*^9}],

Cell[BoxData[
 TemplateBox[{
  "SetBasis","set",
   "\"the state basis has been set to \\!\\(\\*RowBox[{\\\"ZeemanBasis\\\", \
\\\"[\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{\\\"1\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\\\"]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"BasisLabels\\\", \\\"\[Rule]\\\", \\\"Automatic\\\"}]}], \
\\\"]\\\"}]\\).\"",2,9,5,29119468654816436201,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.456163966369556*^9, {3.456164286553218*^9, 3.45616430554272*^9}, 
   3.456164374062786*^9, 3.456164593915292*^9, 3.4562015544899282`*^9, 
   3.456201608205554*^9, 3.4562021802379427`*^9, 3.456202498330545*^9, 
   3.4562028142931004`*^9, 3.456203069214973*^9, 3.456204078992474*^9, 
   3.456204140752467*^9, 3.456204494804265*^9, 3.4562045420959673`*^9, {
   3.456204577367599*^9, 3.456204583615263*^9}, 3.456204854481304*^9, 
   3.45620489799152*^9, 3.461036948022011*^9, 3.461066145853022*^9, 
   3.502942771367139*^9, {3.502943046043352*^9, 3.5029430543488607`*^9}, 
   3.502944776994608*^9, 3.5029449033425407`*^9, 3.51508388392794*^9, 
   3.568902299239889*^9, 3.7121605988088884`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"opR", "[", 
    RowBox[{"{", 
     RowBox[{"\[Beta]", ",", "\"\<x\>\""}], "}"}], "]"}], "]"}], "//", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        FractionBox["\[Beta]", "2"], "]"}], "2"], 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Beta]", "2"], "]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}], 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Beta]", "2"], "]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}], 
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         FractionBox["\[Beta]", "2"], "]"}], "2"]}]},
     {
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Beta]", "2"], "]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}], 
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        FractionBox["\[Beta]", "2"], "]"}], "2"], 
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         FractionBox["\[Beta]", "2"], "]"}], "2"]}], 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Beta]", "2"], "]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}]},
     {
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Beta]", "2"], "]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}], 
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         FractionBox["\[Beta]", "2"], "]"}], "2"]}], 
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        FractionBox["\[Beta]", "2"], "]"}], "2"], 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Beta]", "2"], "]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}]},
     {
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         FractionBox["\[Beta]", "2"], "]"}], "2"]}], 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Beta]", "2"], "]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}], 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Beta]", "2"], "]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}], 
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        FractionBox["\[Beta]", "2"], "]"}], "2"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 4, 8, 12, 16}, {{1}, {3}, {2}, {4}, {1}, {3}, {2}, {4}, {1}, {
       3}, {2}, {4}, {1}, {3}, {2}, {4}}}, {
      Cos[Rational[1, 2] $CellContext`\[Beta]]^2, Complex[0, -1] 
       Cos[Rational[1, 2] $CellContext`\[Beta]] 
       Sin[Rational[1, 2] $CellContext`\[Beta]], Complex[0, -1] 
       Cos[Rational[1, 2] $CellContext`\[Beta]] 
       Sin[Rational[1, 2] $CellContext`\[Beta]], -
       Sin[Rational[1, 2] $CellContext`\[Beta]]^2, Complex[0, -1] 
       Cos[Rational[1, 2] $CellContext`\[Beta]] 
       Sin[Rational[1, 2] $CellContext`\[Beta]], -
       Sin[Rational[1, 2] $CellContext`\[Beta]]^2, 
       Cos[Rational[1, 2] $CellContext`\[Beta]]^2, Complex[0, -1] 
       Cos[Rational[1, 2] $CellContext`\[Beta]] 
       Sin[Rational[1, 2] $CellContext`\[Beta]], Complex[0, -1] 
       Cos[Rational[1, 2] $CellContext`\[Beta]] 
       Sin[Rational[1, 2] $CellContext`\[Beta]], 
       Cos[Rational[1, 2] $CellContext`\[Beta]]^2, -
       Sin[Rational[1, 2] $CellContext`\[Beta]]^2, Complex[0, -1] 
       Cos[Rational[1, 2] $CellContext`\[Beta]] 
       Sin[Rational[1, 2] $CellContext`\[Beta]], -
       Sin[Rational[1, 2] $CellContext`\[Beta]]^2, Complex[0, -1] 
       Cos[Rational[1, 2] $CellContext`\[Beta]] 
       Sin[Rational[1, 2] $CellContext`\[Beta]], Complex[0, -1] 
       Cos[Rational[1, 2] $CellContext`\[Beta]] 
       Sin[Rational[1, 2] $CellContext`\[Beta]], 
       Cos[Rational[1, 2] $CellContext`\[Beta]]^2}}]]]]], "Output",
 CellChangeTimes->{3.5029449114801607`*^9, 3.515083884045182*^9, 
  3.5689023032901206`*^9, 3.7121605989271927`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"opR", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"\[Beta]", ",", "\"\<x\>\""}], "}"}]}], "]"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.502944930638755*^9, 3.502944930765047*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"Cos", "[", 
       FractionBox["\[Beta]", "2"], "]"}], 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}], "0", "0"},
     {
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}], 
      RowBox[{"Cos", "[", 
       FractionBox["\[Beta]", "2"], "]"}], "0", "0"},
     {"0", "0", 
      RowBox[{"Cos", "[", 
       FractionBox["\[Beta]", "2"], "]"}], 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}]},
     {"0", "0", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}], 
      RowBox[{"Cos", "[", 
       FractionBox["\[Beta]", "2"], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 2, 4, 6, 8}, {{1}, {2}, {1}, {2}, {3}, {4}, {3}, {4}}}, {
      Cos[Rational[1, 2] $CellContext`\[Beta]], Complex[0, -1] 
       Sin[Rational[1, 2] $CellContext`\[Beta]], Complex[0, -1] 
       Sin[Rational[1, 2] $CellContext`\[Beta]], Cos[
       Rational[1, 2] $CellContext`\[Beta]], Cos[
       Rational[1, 2] $CellContext`\[Beta]], Complex[0, -1] 
       Sin[Rational[1, 2] $CellContext`\[Beta]], Complex[0, -1] 
       Sin[Rational[1, 2] $CellContext`\[Beta]], Cos[
       Rational[1, 2] $CellContext`\[Beta]]}}]]]]], "Output",
 CellChangeTimes->{{3.5029449114801607`*^9, 3.502944931535563*^9}, 
   3.515083884113246*^9, 3.568902306062279*^9, 3.712160599095041*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"opR", "[", 
    RowBox[{"2", ",", 
     RowBox[{"{", 
      RowBox[{"\[Beta]", ",", "\"\<x\>\""}], "}"}]}], "]"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.502944930638755*^9, 3.502944938134975*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"Cos", "[", 
       FractionBox["\[Beta]", "2"], "]"}], "0", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}], "0"},
     {"0", 
      RowBox[{"Cos", "[", 
       FractionBox["\[Beta]", "2"], "]"}], "0", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}]},
     {
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}], "0", 
      RowBox[{"Cos", "[", 
       FractionBox["\[Beta]", "2"], "]"}], "0"},
     {"0", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Beta]", "2"], "]"}]}], "0", 
      RowBox[{"Cos", "[", 
       FractionBox["\[Beta]", "2"], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 2, 4, 6, 8}, {{1}, {3}, {2}, {4}, {1}, {3}, {2}, {4}}}, {
      Cos[Rational[1, 2] $CellContext`\[Beta]], Complex[0, -1] 
       Sin[Rational[1, 2] $CellContext`\[Beta]], Cos[
       Rational[1, 2] $CellContext`\[Beta]], Complex[0, -1] 
       Sin[Rational[1, 2] $CellContext`\[Beta]], Complex[0, -1] 
       Sin[Rational[1, 2] $CellContext`\[Beta]], Cos[
       Rational[1, 2] $CellContext`\[Beta]], Complex[0, -1] 
       Sin[Rational[1, 2] $CellContext`\[Beta]], Cos[
       Rational[1, 2] $CellContext`\[Beta]]}}]]]]], "Output",
 CellChangeTimes->{{3.5029449114801607`*^9, 3.502944938684998*^9}, 
   3.515083884180279*^9, 3.5689023083884125`*^9, 3.7121605991810975`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3 spins-1/2", "Subsection",
 CellChangeTimes->{{3.50294288940539*^9, 3.502942891122905*^9}, {
  3.5029449504932013`*^9, 3.5029449512593813`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetSpinSystem", "[", "3", "]"}]], "Input",
 CellChangeTimes->{{3.45616396286911*^9, 3.45616396576895*^9}, 
   3.456201606022471*^9, 3.456204541615698*^9, 3.456204576928049*^9, 
   3.5029449538688297`*^9}],

Cell[BoxData[
 TemplateBox[{
  "SetSpinSystem","set",
   "\"the spin system has been set to \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \
FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\
\\\"]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"3\\\", \
\\\",\\\", FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}]}], \\\"}\\\"}]\\)\
\"",2,13,6,29119468654816436201,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.456163966369556*^9, {3.456164286553218*^9, 3.45616430554272*^9}, 
   3.456164374062786*^9, 3.456164593915292*^9, 3.4562015544899282`*^9, 
   3.456201608205554*^9, 3.4562021802379427`*^9, 3.456202498330545*^9, 
   3.4562028142931004`*^9, 3.456203069214973*^9, 3.456204078992474*^9, 
   3.456204140752467*^9, 3.456204494804265*^9, 3.4562045420959673`*^9, {
   3.456204577367599*^9, 3.456204583615263*^9}, 3.456204854481304*^9, 
   3.45620489799152*^9, 3.461036948022011*^9, 3.461066145853022*^9, 
   3.502942771367139*^9, {3.502943046043352*^9, 3.5029430543488607`*^9}, 
   3.502944776994608*^9, 3.5029449033425407`*^9, 3.502944954406087*^9, 
   3.515083884247746*^9, 3.568902311309579*^9, 3.712160599196109*^9}],

Cell[BoxData[
 TemplateBox[{
  "SetBasis","set",
   "\"the state basis has been set to \\!\\(\\*RowBox[{\\\"ZeemanBasis\\\", \
\\\"[\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{\\\"1\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\\\"]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"3\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\
\\\"]}], \\\"}\\\"}]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"BasisLabels\\\", \
\\\"\[Rule]\\\", \\\"Automatic\\\"}]}], \\\"]\\\"}]\\).\"",2,13,7,
   29119468654816436201,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.456163966369556*^9, {3.456164286553218*^9, 3.45616430554272*^9}, 
   3.456164374062786*^9, 3.456164593915292*^9, 3.4562015544899282`*^9, 
   3.456201608205554*^9, 3.4562021802379427`*^9, 3.456202498330545*^9, 
   3.4562028142931004`*^9, 3.456203069214973*^9, 3.456204078992474*^9, 
   3.456204140752467*^9, 3.456204494804265*^9, 3.4562045420959673`*^9, {
   3.456204577367599*^9, 3.456204583615263*^9}, 3.456204854481304*^9, 
   3.45620489799152*^9, 3.461036948022011*^9, 3.461066145853022*^9, 
   3.502942771367139*^9, {3.502943046043352*^9, 3.5029430543488607`*^9}, 
   3.502944776994608*^9, 3.5029449033425407`*^9, 3.502944954406087*^9, 
   3.515083884247746*^9, 3.568902311309579*^9, 3.712160599238139*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ispins", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}]}], ";", " ", 
  RowBox[{"Sspins", "=", 
   RowBox[{"{", "3", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.502944956329289*^9, 3.502944965188512*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"opR", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Pi]", "/", "2"}], ",", "\"\<x\>\""}], "}"}], "]"}], "]"}], "//",
   "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.5029449710227013`*^9, 3.502944978868751*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["1", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      FractionBox["\[ImaginaryI]", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]]},
     {
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      FractionBox["1", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]], 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      FractionBox["\[ImaginaryI]", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]], 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}]},
     {
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      FractionBox["1", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      FractionBox["\[ImaginaryI]", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}]},
     {
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      FractionBox["1", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]], 
      FractionBox["\[ImaginaryI]", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]], 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}]},
     {
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      FractionBox["\[ImaginaryI]", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]], 
      FractionBox["1", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}]},
     {
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      FractionBox["\[ImaginaryI]", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]], 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      FractionBox["1", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]], 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}]},
     {
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      FractionBox["\[ImaginaryI]", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      FractionBox["1", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}]},
     {
      FractionBox["\[ImaginaryI]", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]], 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]]}], 
      FractionBox["1", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {8, 8}, 0, {
     1, {{0, 8, 16, 24, 32, 40, 48, 56, 64}, {{1}, {5}, {3}, {7}, {2}, {6}, {
       4}, {8}, {1}, {5}, {3}, {7}, {2}, {6}, {4}, {8}, {1}, {5}, {3}, {7}, {
       2}, {6}, {4}, {8}, {1}, {5}, {3}, {7}, {2}, {6}, {4}, {8}, {1}, {5}, {
       3}, {7}, {2}, {6}, {4}, {8}, {1}, {5}, {3}, {7}, {2}, {6}, {4}, {8}, {
       1}, {5}, {3}, {7}, {2}, {6}, {4}, {8}, {1}, {5}, {3}, {7}, {2}, {6}, {
       4}, {8}}}, {
      Rational[1, 2] 2^Rational[-1, 2], Complex[0, Rational[-1, 2]] 
       2^Rational[-1, 2], Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], 
       Rational[-1, 2] 2^Rational[-1, 2], Complex[0, Rational[-1, 2]] 
       2^Rational[-1, 2], Rational[-1, 2] 2^Rational[-1, 2], Rational[-1, 2] 
       2^Rational[-1, 2], Complex[0, Rational[1, 2]] 2^Rational[-1, 2], 
       Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], Rational[-1, 2] 
       2^Rational[-1, 2], Rational[-1, 2] 2^Rational[-1, 2], 
       Complex[0, Rational[1, 2]] 2^Rational[-1, 2], Rational[1, 2] 
       2^Rational[-1, 2], Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], 
       Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], Rational[-1, 2] 
       2^Rational[-1, 2], Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], 
       Rational[-1, 2] 2^Rational[-1, 2], Rational[1, 2] 2^Rational[-1, 2], 
       Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], Rational[-1, 2] 
       2^Rational[-1, 2], Complex[0, Rational[1, 2]] 2^Rational[-1, 2], 
       Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], Rational[-1, 2] 
       2^Rational[-1, 2], Rational[-1, 2] 2^Rational[-1, 2], 
       Complex[0, Rational[1, 2]] 2^Rational[-1, 2], 
       Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], Rational[-1, 2] 
       2^Rational[-1, 2], Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], 
       Rational[-1, 2] 2^Rational[-1, 2], Rational[1, 2] 2^Rational[-1, 2], 
       Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], 
       Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], Rational[1, 2] 
       2^Rational[-1, 2], Rational[-1, 2] 2^Rational[-1, 2], 
       Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], Rational[-1, 2] 
       2^Rational[-1, 2], Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], 
       Complex[0, Rational[1, 2]] 2^Rational[-1, 2], Rational[-1, 2] 
       2^Rational[-1, 2], Rational[-1, 2] 2^Rational[-1, 2], 
       Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], 
       Complex[0, Rational[1, 2]] 2^Rational[-1, 2], Rational[-1, 2] 
       2^Rational[-1, 2], Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], 
       Rational[1, 2] 2^Rational[-1, 2], Rational[-1, 2] 2^Rational[-1, 2], 
       Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], Rational[-1, 2] 
       2^Rational[-1, 2], Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], 
       Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], Rational[1, 2] 
       2^Rational[-1, 2], Complex[0, Rational[1, 2]] 2^Rational[-1, 2], 
       Rational[-1, 2] 2^Rational[-1, 2], Rational[-1, 2] 2^Rational[-1, 2], 
       Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], 
       Complex[0, Rational[1, 2]] 2^Rational[-1, 2], Rational[-1, 2] 
       2^Rational[-1, 2], Rational[-1, 2] 2^Rational[-1, 2], 
       Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], Rational[-1, 2] 
       2^Rational[-1, 2], Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], 
       Complex[0, Rational[-1, 2]] 2^Rational[-1, 2], Rational[1, 2] 
       2^Rational[-1, 2]}}]]]]], "Output",
 CellChangeTimes->{
  3.5029449114801607`*^9, {3.502944968175857*^9, 3.502944979336422*^9}, 
   3.5150838844497433`*^9, 3.568902317900956*^9, 3.712160599351719*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"opR", "[", 
    RowBox[{"Ispins", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Pi]", "/", "2"}], ",", "\"\<x\>\""}], "}"}]}], "]"}], "]"}],
   "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.502944930638755*^9, 3.502944930765047*^9}, {
  3.502944983534555*^9, 3.502944988860811*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], "0", "0", "0", "0"},
     {
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}], 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}], "0", "0", "0", "0"},
     {
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}], "0", "0", "0", "0"},
     {
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}], 
      FractionBox["1", "2"], "0", "0", "0", "0"},
     {"0", "0", "0", "0", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]},
     {"0", "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}], 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}]},
     {"0", "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}]},
     {"0", "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}], 
      FractionBox["1", "2"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {8, 8}, 0, {
     1, {{0, 4, 8, 12, 16, 20, 24, 28, 32}, {{1}, {3}, {2}, {4}, {1}, {3}, {
       2}, {4}, {1}, {3}, {2}, {4}, {1}, {3}, {2}, {4}, {5}, {7}, {6}, {8}, {
       5}, {7}, {6}, {8}, {5}, {7}, {6}, {8}, {5}, {7}, {6}, {8}}}, {
      Rational[1, 2], Complex[0, Rational[-1, 2]], Complex[
       0, Rational[-1, 2]], Rational[-1, 2], Complex[0, Rational[-1, 2]], 
       Rational[-1, 2], Rational[1, 2], Complex[0, Rational[-1, 2]], Complex[
       0, Rational[-1, 2]], Rational[1, 2], Rational[-1, 2], Complex[
       0, Rational[-1, 2]], Rational[-1, 2], Complex[0, Rational[-1, 2]], 
       Complex[0, Rational[-1, 2]], Rational[1, 2], Rational[1, 2], Complex[
       0, Rational[-1, 2]], Complex[0, Rational[-1, 2]], Rational[-1, 2], 
       Complex[0, Rational[-1, 2]], Rational[-1, 2], Rational[1, 2], Complex[
       0, Rational[-1, 2]], Complex[0, Rational[-1, 2]], Rational[1, 2], 
       Rational[-1, 2], Complex[0, Rational[-1, 2]], Rational[-1, 2], Complex[
       0, Rational[-1, 2]], Complex[0, Rational[-1, 2]], Rational[
       1, 2]}}]]]]], "Output",
 CellChangeTimes->{{3.5029449114801607`*^9, 3.502944931535563*^9}, 
   3.5029449895306673`*^9, 3.515083884518734*^9, 3.5689023232182603`*^9, 
   3.7121605995293474`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"opR", "[", 
    RowBox[{"Sspins", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Pi]", "/", "2"}], ",", "\"\<x\>\""}], "}"}]}], "]"}], "]"}],
   "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.502944930638755*^9, 3.502944938134975*^9}, {
  3.5029449955029078`*^9, 3.502944997484906*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["1", 
       SqrtBox["2"]], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        SqrtBox["2"]]}], "0", "0", "0"},
     {"0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        SqrtBox["2"]]}], "0", "0"},
     {"0", "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        SqrtBox["2"]]}], "0"},
     {"0", "0", "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        SqrtBox["2"]]}]},
     {
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        SqrtBox["2"]]}], "0", "0", "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", "0", "0"},
     {"0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        SqrtBox["2"]]}], "0", "0", "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", "0"},
     {"0", "0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        SqrtBox["2"]]}], "0", "0", "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0"},
     {"0", "0", "0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        SqrtBox["2"]]}], "0", "0", "0", 
      FractionBox["1", 
       SqrtBox["2"]]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {8, 8}, 0, {
     1, {{0, 2, 4, 6, 8, 10, 12, 14, 16}, {{1}, {5}, {2}, {6}, {3}, {7}, {
       4}, {8}, {1}, {5}, {2}, {6}, {3}, {7}, {4}, {8}}}, {
      2^Rational[-1, 2], Complex[0, -1] 2^Rational[-1, 2], 2^Rational[-1, 2], 
       Complex[0, -1] 2^Rational[-1, 2], 2^Rational[-1, 2], Complex[0, -1] 
       2^Rational[-1, 2], 2^Rational[-1, 2], Complex[0, -1] 2^Rational[-1, 2],
        Complex[0, -1] 2^Rational[-1, 2], 2^Rational[-1, 2], Complex[0, -1] 
       2^Rational[-1, 2], 2^Rational[-1, 2], Complex[0, -1] 2^Rational[-1, 2],
        2^Rational[-1, 2], Complex[0, -1] 2^Rational[-1, 2], 2^
       Rational[-1, 2]}}]]]]], "Output",
 CellChangeTimes->{{3.5029449114801607`*^9, 3.502944938684998*^9}, 
   3.502944997966764*^9, 3.515083884585889*^9, 3.5689023256964025`*^9, 
   3.7121605995543823`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1149, 730},
WindowMargins->{{6, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowSelection->True,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"mhl-default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info23712164197-7500259"->{
  Cell[2147, 64, 954, 13, 96, "Print",
   CellTags->"Info23712164197-7500259"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info23712164197-7500259", 54847, 1497}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 195, 3, 30, "Input"],
Cell[765, 27, 149, 4, 36, "Print"],
Cell[917, 33, 836, 15, 40, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1790, 53, 166, 2, 28, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1981, 59, 163, 3, 30, "Input"],
Cell[2147, 64, 954, 13, 96, "Print",
 CellTags->"Info23712164197-7500259"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3138, 82, 126, 2, 43, "Subsection"],
Cell[CellGroupData[{
Cell[3289, 88, 130, 2, 30, "Input"],
Cell[3422, 92, 433, 8, 47, "Message"],
Cell[3858, 102, 575, 11, 47, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4470, 118, 281, 6, 30, "Input"],
Cell[4754, 126, 857, 16, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5648, 147, 272, 7, 30, "Input"],
Cell[5923, 156, 1422, 38, 86, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7382, 199, 267, 7, 30, "Input"],
Cell[7652, 208, 1742, 45, 86, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9431, 258, 287, 7, 30, "Input"],
Cell[9721, 267, 2871, 73, 100, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12629, 345, 327, 9, 30, "Input"],
Cell[12959, 356, 6878, 168, 110, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19886, 530, 98, 1, 43, "Subsection"],
Cell[CellGroupData[{
Cell[20009, 535, 200, 3, 30, "Input"],
Cell[20212, 540, 1157, 20, 47, "Message"],
Cell[21372, 562, 1297, 21, 47, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22706, 588, 205, 6, 30, "Input"],
Cell[22914, 596, 4795, 125, 146, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27746, 726, 298, 8, 30, "Input"],
Cell[28047, 736, 2146, 56, 146, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30230, 797, 298, 8, 30, "Input"],
Cell[30531, 807, 2150, 56, 146, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[32730, 869, 151, 2, 43, "Subsection"],
Cell[CellGroupData[{
Cell[32906, 875, 228, 4, 30, "Input"],
Cell[33137, 881, 1292, 21, 47, "Message"],
Cell[34432, 904, 1435, 23, 47, "Message"]
}, Open  ]],
Cell[35882, 930, 254, 7, 30, "Input"],
Cell[CellGroupData[{
Cell[36161, 941, 298, 8, 30, "Input"],
Cell[36462, 951, 10616, 317, 282, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47115, 1273, 378, 10, 30, "Input"],
Cell[47496, 1285, 3724, 99, 258, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51257, 1389, 380, 10, 30, "Input"],
Cell[51640, 1401, 2704, 77, 282, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

